<?php

namespace Realestate\Testimonial\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Realestate\Testimonial\Http\Resources\TestimonialResource;
use Realestate\Testimonial\Http\Resources\TestimonialsCollection;
use Realestate\Testimonial\Scopes\TestimonialPublicScope;
use Realestate\Testimonial\Models\Testimonial;

class TestimonialPublicController extends BaseController
{

    /**
     * Show testimonial's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Testimonial::pushScope(new RequestScope())
            ->pushScope(new TestimonialPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $testimonials = new TestimonialsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('testimonial::testimonial.names'))
            ->view('testimonial::public.testimonial.index')
            ->data(compact('testimonials', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show testimonial.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Testimonial::findBySlug($slug);
        $data = new TestimonialResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('testimonial::testimonial.name'))
            ->view('testimonial::public.testimonial.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
