<?php

namespace Realestate\Testimonial\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Realestate\Testimonial\Events\TestimonialAction as TestimonialActionEvent;
use Realestate\Testimonial\Notifications\TestimonialAction as TestimonialActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TestimonialAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TestimonialActionEvent.
     *
     * @param   TestimonialActionEvent  $event
     * @return mixed
     */
    public function handle(TestimonialActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $testimonial.
     *
     * @param   TestimonialActionEvent  $event
     * @return void
     */
    public function create(TestimonialActionEvent $event)
    {
        $client = $event->testimonial->client;
        Notification::send($client, new TestimonialActionNotification($event));
    }

    /**
     * Handle the TestimonialActionEvent as a listener.
     *
     * @param   TestimonialActionEvent  $event
     * @return mixed
     */
    public function asListener(TestimonialActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TestimonialActionEvent  $event
     * @return bool
     */
    private function isAllowed(TestimonialActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
