<?php

namespace Realestate\Testimonial\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Realestate\Testimonial\Events\TestimonialWorkflow as TestimonialWorkflowEvent;
use Realestate\Testimonial\Notifications\TestimonialWorkflow as TestimonialWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class TestimonialWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(TestimonialWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $testimonial is submitted.
     *
     * @param TestimonialWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(TestimonialWorkflowEvent $event)
    {
        $client = $event->testimonial->client;
        Notification::send($client, new TestimonialWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $testimonial is published.
     *
     * @param TestimonialWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(TestimonialWorkflowEvent $event)
    {
        $client = $event->testimonial->client;
        Notification::send($client, new TestimonialWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $testimonial is approved.
     *
     * @param TestimonialWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(TestimonialWorkflowEvent $event)
    {
        $client = $event->testimonial->client;
        Notification::send($client, new TestimonialWorkflowNotification($event));
    }

    /**
     * Handles the $testimonial workflow event as a listener.
     *
     * @param TestimonialWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(TestimonialWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
